
# Slot: chi squared statistic


represents the chi-squared statistic computed from observations

URI: [biolink:chi_squared_statistic](https://w3id.org/biolink/vocab/chi_squared_statistic)


## Domain and Range

[Association](Association.md) &#8594;  <sub>0..1</sub> [Float](types/Float.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | STATO:0000030 |

